==> smokejs-2.2.4.tgz: package/README.md <==
#[Smoke](http://alfredobarron.github.io/smoke)

![Version](https://img.shields.io/github/release/alfredobarron/smoke.svg)
![Version](https://img.shields.io/bower/v/smoke.svg)


Smoke is the most complete jQuery Plugin and designed for use with Bootstrap 3



To get started, check out [http://alfredobarron.github.io/smoke/#/](http://alfredobarron.github.io/smoke/#/)


## Table of contents

 - [Quick start](#quick-start)
 - [Required](#required)
 - [Documentation](#documentation)
 - [How to contribute](#how-to-contribute)
 - [Community](#community)
 - [Creators](#creators)
 - [Collaborators](#collaborators)
 - [Copyright and license](#copyright-and-license)




## Quick start

Several quick start options are available:

- [Download the latest release](https://github.com/alfredobarron/smoke/archive/master.zip)
- Clone the repo: `git clone https://github.com/alfredobarron/smoke.git`.
- Install with [Bower](http://bower.io/): `bower install smoke`.

Read the [Getting started page](http://alfredobarron.github.io/smoke/#/getting-started) for information on the plugin contents.



##Required

Smoke plugin requires the [Jquery](http://jquery.com/) library and [Bootstrap 3.](http://getbootstrap.com/) framework.



##Documentation

Documentation can check the [http://alfredobarron.github.io/smoke/#/](http://alfredobarron.github.io/smoke/#/)

##How to contribute

All contributions are very welcome, We love it. There are several ways to help out:

- Create an issue on GitHub, if you have found a bug
- Write test cases for open bug issues
- Write patches for open bug/feature issues, preferably with test cases included
- Contribute to the documentation

There are a few guidelines that we need contributors to follow so that we have a chance of keeping on top of things.


If you want to making changes Better avoid working directly on the master branch, to avoid conflicts if you pull in updates from origin, so, if make your contribution under the branch [`dev`](https://github.com/alfredobarron/smoke/tree/dev).


##Community

- Join [the official Slack room](https://smokejs.slack.com).
- Implementation help may be found at Stack Overflow (tagged [`smoke`](http://stackoverflow.com/questions/tagged/smoke)).


##Creators

[@AlfredoBarronC](https://twitter.com/AlfredoBarronC)



##Collaborators

- [+MisaelRojas](https://plus.google.com/+MisaelRojas)
- [@mostrosonido](https://twitter.com/mostrosonido)
- [@sdhp](https://github.com/sdhp)
- [@LespiletteMaxime](https://github.com/LespiletteMaxime)
- [@druzza](https://github.com/druzza)



##Copyright and license

Code and documentation (c) Copyright 2015 Alfredo Barron. Code published under [license LGPL](https://github.com/alfredobarron/smoke/blob/master/LICENSE)

==> smokejs-3.0.0.tgz: package/README.md <==
#[Smoke](http://alfredobarron.github.io/smoke)

![Version](https://img.shields.io/github/release/alfredobarron/smoke.svg)
![Version](https://img.shields.io/bower/v/smoke.svg)
![Version](https://img.shields.io/npm/v/smokejs.svg)



Smoke form validation and components for Bootstrap



To get started, check out [http://alfredobarron.github.io/smoke/](http://alfredobarron.github.io/smoke/)


## Table of contents

 - [Quick start](#quick-start)
 - [Required](#required)
 - [Documentation](#documentation)
 - [How to contribute](#how-to-contribute)
 - [Community](#community)
 - [Creators](#creators)
 - [Collaborators](#collaborators)
 - [Copyright and license](#copyright-and-license)




## Quick start

Several quick start options are available:

- [Download the latest release](https://github.com/alfredobarron/smoke/archive/master.zip)
- Clone the repo: `git clone https://github.com/alfredobarron/smoke.git`.
- Install with [Bower](http://bower.io/): `bower install smoke`.
- Install with [npm](https://www.npmjs.com): `npm install smokejs`.


Read the [Getting started page](http://alfredobarron.github.io/smoke/#/getting-started) for information on the plugin contents.



##Required

Smoke plugin requires the [Jquery](http://jquery.com/) library and [Bootstrap 3.](http://getbootstrap.com/) framework.



##Documentation

Documentation can check the [http://alfredobarron.github.io/smoke/](http://alfredobarron.github.io/smoke/)

##How to contribute

All contributions are very welcome, We love it. There are several ways to help out:

- Create an issue on GitHub, if you have found a bug
- Write test cases for open bug issues
- Write patches for open bug/feature issues, preferably with test cases included
- Contribute to the documentation

There are a few guidelines that we need contributors to follow so that we have a chance of keeping on top of things.


If you want to making changes Better avoid working directly on the master branch, to avoid conflicts if you pull in updates from origin, so, if make your contribution under the branch [`dev`](https://github.com/alfredobarron/smoke/tree/dev).


##Community

- Join [the official Slack room](https://smokejs.slack.com).
- Implementation help may be found at Stack Overflow (tagged [`smoke`](http://stackoverflow.com/questions/tagged/smoke)).


##Creators

[@AlfredoBarronC](https://twitter.com/AlfredoBarronC)



##Collaborators

- [+MisaelRojas](https://plus.google.com/+MisaelRojas)
- [@mostrosonido](https://twitter.com/mostrosonido)
- [@sdhp](https://github.com/sdhp)
- [@LespiletteMaxime](https://github.com/LespiletteMaxime)
- [@druzza](https://github.com/druzza)
- [@adaniello](https://github.com/adaniello)
- [@tamerwaw](https://github.com/tamerwaw)
- [@itsromack](https://github.com/itsromack)



##Copyright and license

Code and documentation (c) Copyright 2015 Alfredo Barron. Code published under [license LGPL](https://github.com/alfredobarron/smoke/blob/master/LICENSE)
